======
safpis
======


.. image:: https://img.shields.io/pypi/v/safpis.svg
     :target: https://pypi.python.org/pypi/safpis

.. image:: https://img.shields.io/github/actions/workflow/status/nathanhaigh/safpis/python-package.yml
     :target: https://github.com/nathanhaigh/safpis/actions/workflows/python-package.yml

.. image:: https://img.shields.io/readthedocs/safpis
     :target: https://safpis.readthedocs.io/en/latest/?version=latest
     :alt: Documentation Status

.. image:: https://img.shields.io/codecov/c/github/nathanhaigh/safpis
     :target: https://app.codecov.io/gh/nathanhaigh/safpis

.. image:: https://img.shields.io/badge/code%20style-black-black
     :target: https://black.readthedocs.io/en/stable/

.. image:: https://img.shields.io/badge/License-MIT-yellow.svg
     :target: https://opensource.org/licenses/MIT


safpis is a Python library to access the South Australia Fuel Pricing
Information Scheme (SAFPIS) REST API.

To use this library you will first need to register to become an SAFPIS Data
Publisher and receive a Subscriber Token. Visit https://www.safuelpricinginformation.com.au/
for more information and details about registering to become a Data Publisher.

The SAFPIS is a mechanism through which Fuel Retailers are required, by law, to
report their fuel prices and Data Publishers can access the data via a REST
API.

* Free software: MIT license
* Documentation: https://safpis.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
